pub fn file_type(metadata: &Metadata) -> Result<FileType, Error>Expand description
Try getting the fuser::FileType from a std::fs::Metadata.
For now, this only supports directories, files, and symlinks.
pub fn file_type(metadata: &Metadata) -> Result<FileType, Error>Try getting the fuser::FileType from a std::fs::Metadata.
For now, this only supports directories, files, and symlinks.