pub trait InodeAllocator {
type Error;
// Required method
fn allocate<'life0, 'async_trait>(
&'life0 mut self,
n: usize,
) -> Pin<Box<dyn Future<Output = Result<u64, Self::Error>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
}Required Associated Types
Required Methods
Sourcefn allocate<'life0, 'async_trait>(
&'life0 mut self,
n: usize,
) -> Pin<Box<dyn Future<Output = Result<u64, Self::Error>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn allocate<'life0, 'async_trait>(
&'life0 mut self,
n: usize,
) -> Pin<Box<dyn Future<Output = Result<u64, Self::Error>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Reserve a continuous number of inodes, returning the start. The range is disjoint from the previously allocated ones.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".